<?php

namespace Litecms\Exchangeorder\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Exchangeorder\Http\Requests\ExchangeorderRequest;
use Litecms\Exchangeorder\Models\Exchangeorder;

/**
 * Admin web controller class.
 */
class ExchangeorderWorkflowController extends BaseController
{

    /**
     * Workflow controller function for exchangeorder.
     *
     * @param Model   $exchangeorder
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ExchangeorderRequest $request, Exchangeorder $exchangeorder, $step)
    {

        try {

            $exchangeorder->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('exchangeorder::exchangeorder.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/exchangeorder/exchangeorder/' . $exchangeorder->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/exchangeorder/exchangeorder/' . $exchangeorder->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for exchangeorder.
     *
     * @param Model   $exchangeorder
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Exchangeorder $exchangeorder, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $exchangeorder->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('exchangeorder::exchangeorder.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('exchangeorder::admin.exchangeorder.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('exchangeorder::admin.exchangeorder.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('exchangeorder::admin.exchangeorder.message', $data)->render();

        }

    }
}
