<?php

namespace Litecms\Exchangeorder\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Exchangeorder\Models\Exchangeorder;

class ExchangeorderPolicy
{

    /**
     * Determine if the given user can view the exchangeorder.
     *
     * @param UserPolicy $user
     * @param Exchangeorder $exchangeorder
     *
     * @return bool
     */
    public function view(UserPolicy $user, Exchangeorder $exchangeorder)
    {
        if ($user->canDo('exchangeorder.exchangeorder.view') && $user->isAdmin()) {
            return true;
        }

        return $exchangeorder->user_id == user_id() && $exchangeorder->user_type == user_type();
    }

    /**
     * Determine if the given user can create a exchangeorder.
     *
     * @param UserPolicy $user
     * @param Exchangeorder $exchangeorder
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('exchangeorder.exchangeorder.create');
    }

    /**
     * Determine if the given user can update the given exchangeorder.
     *
     * @param UserPolicy $user
     * @param Exchangeorder $exchangeorder
     *
     * @return bool
     */
    public function update(UserPolicy $user, Exchangeorder $exchangeorder)
    {
        if ($user->canDo('exchangeorder.exchangeorder.edit') && $user->isAdmin()) {
            return true;
        }

        return $exchangeorder->user_id == user_id() && $exchangeorder->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given exchangeorder.
     *
     * @param UserPolicy $user
     * @param Exchangeorder $exchangeorder
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Exchangeorder $exchangeorder)
    {
        return $exchangeorder->user_id == user_id() && $exchangeorder->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given exchangeorder.
     *
     * @param UserPolicy $user
     * @param Exchangeorder $exchangeorder
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Exchangeorder $exchangeorder)
    {
        if ($user->canDo('exchangeorder.exchangeorder.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given exchangeorder.
     *
     * @param UserPolicy $user
     * @param Exchangeorder $exchangeorder
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Exchangeorder $exchangeorder)
    {
        if ($user->canDo('exchangeorder.exchangeorder.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
